@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 1999-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 1999-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you did
  * not receive this file, http://www.horde.org/licenses/lgpl21
@@ -71,10 +71,10 @@ class Horde_Auth
      * @return Horde_Auth_Base  The newly created concrete instance.
      * @throws Horde_Auth_Exception
      */
-    static public function factory($driver, $params = null)
+    public static function factory($driver, $params = null)
     {
         /* Base drivers (in Auth/ directory). */
-        $class = __CLASS__ . '_' . ucfirst($driver);
+        $class = __CLASS__ . '_' . Horde_String::ucfirst($driver);
         if (@class_exists($class)) {
             return new $class($params);
         }
@@ -103,7 +103,7 @@ class Horde_Auth
      *
      * @return string  The encrypted password.
      */
-    static public function getCryptedPassword($plaintext, $salt = '',
+    public static function getCryptedPassword($plaintext, $salt = '',
                                               $encryption = 'md5-hex',
                                               $show_encrypt = false)
     {
@@ -218,7 +218,7 @@ class Horde_Auth
      *
      * @return string  The generated or extracted salt.
      */
-    static public function getSalt($encryption = 'md5-hex', $seed = '',
+    public static function getSalt($encryption = 'md5-hex', $seed = '',
                                    $plaintext = '')
     {
         switch ($encryption) {
@@ -242,8 +242,8 @@ class Horde_Auth
 
         case 'crypt-blowfish':
             return $seed
-                ? substr(preg_replace('|^{crypt}|i', '', $seed), 0, 16)
-                : '$2$' . base64_encode(hash('md5', sprintf('%08X%08X%08X', mt_rand(), mt_rand(), mt_rand()), true)) . '$';
+                ? preg_replace('|^(?:{crypt})?(\$2.?\$(?:\d\d\$)?[0-9A-Za-z./]{22}).*|i', '$1', $seed)
+                : '$2$' . substr(base64_encode(hash('md5', sprintf('%08X%08X%08X', mt_rand(), mt_rand(), mt_rand()), true)), 0, 21) . '$';
 
         case 'crypt-md5':
             return $seed
@@ -293,7 +293,7 @@ class Horde_Auth
      *
      * @return string  $value converted to the 64 MD5 characters.
      */
-    static protected function _toAPRMD5($value, $count)
+    protected static function _toAPRMD5($value, $count)
     {
         $aprmd5 = '';
         $count = abs($count);
@@ -313,7 +313,7 @@ class Horde_Auth
      *
      * @return string A random password
      */
-    static public function genRandomPassword()
+    public static function genRandomPassword()
     {
         /* Alternate consonant and vowel random chars with two random numbers
          * at the end. This should produce a fairly pronounceable password. */
@@ -363,7 +363,7 @@ class Horde_Auth
      *
      * @throws Horde_Auth_Exception if the password does not match the policy.
      */
-    static public function checkPasswordPolicy($password, array $policy)
+    public static function checkPasswordPolicy($password, array $policy)
     {
         // Check max/min lengths if specified in the policy.
         if (isset($policy['minLength']) &&
@@ -436,7 +436,7 @@ class Horde_Auth
      *
      * @throws Horde_Auth_Exception if the password is too similar.
      */
-    static public function checkPasswordSimilarity($password, array $dict,
+    public static function checkPasswordSimilarity($password, array $dict,
                                                    $max = 80)
     {
         // Check for pass == dict, simple reverse strings, etc.
