@@ -2,7 +2,7 @@
 /**
  * Test the Horde_Auth:: class.
  *
- * Copyright 2010-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2010-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -27,8 +27,8 @@ class Horde_Auth_Unit_AuthTest extends Horde_Auth_TestCase
     /**
      * @dataProvider getCredentials
      */
-    public function testGetCryptedPassword($encryption, $password, $salt)
+    public function testGetCryptedPassword($encryption, $password, $salt, $show_encryption = false)
     {
-        $this->assertEquals($password, Horde_Auth::getCryptedPassword('foobar', $password, $encryption, false));
+        $this->assertEquals($password, Horde_Auth::getCryptedPassword('foobar', $password, $encryption, $show_encryption));
     }
 }
